# pydear 🦌


```{toctree}
:maxdepth: 1
basic/index
nodes/index
imgui/index
```

```{toctree}
:caption: autodoc
autodoc/modules
modindex
```

```{toctree}
:caption: external
repository <https://github.com/ousttrue/pydear>
gh-pages <https://ousttrue.github.io/pydear/>
pypi <https://pypi.org/project/pydear/>
```

{ref}`modindex`
